package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.ActSuppliesHistorydata;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 *  历史数据Mapper接口
 *
 * @author dongjg
 * @date 2023-08-01
 */
@Repository
public interface ActSuppliesHistorydataMapper
{
    /**
     * 查询 历史数据
     *
     * @param id  历史数据ID
     * @return  历史数据
     */
    public ActSuppliesHistorydata selectActSuppliesHistorydataById(Long id);

    /**
     * 查询 历史数据列表
     *
     * @param actSuppliesHistorydata  历史数据
     * @return  历史数据集合
     */
    public List<ActSuppliesHistorydata> selectActSuppliesHistorydataList(ActSuppliesHistorydata actSuppliesHistorydata);

    /**
     * 新增 历史数据
     *
     * @param actSuppliesHistorydata  历史数据
     * @return 结果
     */
    public int insertActSuppliesHistorydata(ActSuppliesHistorydata actSuppliesHistorydata);

    /**
     * 修改 历史数据
     *
     * @param actSuppliesHistorydata  历史数据
     * @return 结果
     */
    public int updateActSuppliesHistorydata(ActSuppliesHistorydata actSuppliesHistorydata);

    /**
     * 删除 历史数据
     *
     * @param id  历史数据ID
     * @return 结果
     */
    public int deleteActSuppliesHistorydataById(Long id);

    /**
     * 批量删除 历史数据
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteActSuppliesHistorydataByIds(Long[] ids);

    Long[] selectActSuppliesRole(Long templateId);

    List<ActSuppliesHistorydata> selectActSuppliesHistorydatauuid(ActSuppliesHistorydata actSuppliesHistorydata);

    void insertActSuppliesHistorydatas(ActSuppliesHistorydata actSuppliesHistorydata1);

    void updateActSuppliesHistorydatas(ActSuppliesHistorydata actSuppliesHistorydata);

    /**
     * 获取所有历史数据
     *
     * @return 结果
     */
    List<ActSuppliesHistorydata> selectActSuppliesHistorydata(Integer tylkStatus);

    int updateActSuppliesHistorydataStatusById(Long gethId);
    /**
     * 修改历史表数据内容表
     *
     * @return 结果
     */
    void updateActSUppliesHistoryContent(ActSuppliesHistorydata actSuppliesHistorydata);
    /**
     * 新增历史表数据内容表
     *
     * @return 结果
     */
    void insertActSuppliesHistorycontent(ActSuppliesHistorydata actSuppliesHistorydata);

    void insertActSuppliesHistorydataAcc(ActSuppliesHistorydata actSuppliesHistorydata1);

    void insertActSuppliesHistorycontentAcc(ActSuppliesHistorydata actSuppliesHistorydata1);

    void updateActSuppliesHistorydataStatusByIdAcc(Long gethId);

    List<ActSuppliesHistorydata> selectActSuppliesHistorydataAcc(ActSuppliesHistorydata actSuppliesHistorydata);

    List<ActSuppliesHistorydata> selectActSuppliesHistorydataCopyList(ActSuppliesHistorydata actSuppliesHistorydata);

    ActSuppliesHistorydata selectActSuppliesHistorydataCopyById(Long id);

    public int  deleteActSuppliesHistorycontentById(String importUuid);

    public int  deleteActSuppliesHistorycontentByIds(String[] importUuid);
}
